Product class

Constructors

Product({required String id, required String name, required double price, String? category, String? brand, int? stockQuantity})

Properties

brand String?
final
category String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
price double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stockQuantity int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited